@@ -54,13 +54,13 @@ def disconnect(sock):
     
     sock.close()
 
-def read(sock, get=False):
+def read(sock, get=False, data=False):
     '''Metod that reads messages from server and returns dict containing server response
     if get parameter is set to True.
     
     Return examples:
     {"header": "200, "body": "OK"}
-    {"header": "200 data follow", "body": str}
+    {"header": "200", "body": "data follow"}
     
     :sock socket
     :get bool
@@ -70,8 +70,9 @@ def read(sock, get=False):
     
     message = {}
 
-    msg = sock.recv(4).decode()
-    message['header'] = msg.strip()
+    if not data:
+        msg = sock.recv(4).decode()
+        message['header'] = msg.strip()
 
     full = ''
     while True:
@@ -91,4 +92,4 @@ def read(sock, get=False):
             break
 
     if 'get':
-        return message
\ No newline at end of file
+        return message       
\ No newline at end of file
